document.addEventListener('DOMContentLoaded', function () {
    const cameraPlaceholder = document.getElementById('camera-placeholder');
    const cameraPreview = document.getElementById('camera-preview');
    const cameraView = document.getElementById('camera-view');
    const captureButton = document.getElementById('capture-button');
    const capturedImageContainer = document.getElementById('captured-image-container');
    const capturedImage = document.getElementById('captured-image');
    const retakeButton = document.getElementById('retake-button');
    const confirmButton = document.getElementById('confirm-button');
    const serialNumberInput = document.getElementById('serial-number');

    let stream = null;
    let capturedPhoto = null; // To store the captured photo as a base64 string

    // Function to check camera permission
    const checkCameraPermission = async () => {
        if (!navigator.permissions || !navigator.permissions.query) {
            console.log('Permissions API not supported');
            return 'unsupported';
        }

        try {
            const permissionStatus = await navigator.permissions.query({ name: 'camera' });
            return permissionStatus.state;
        } catch (error) {
            console.error('Error checking camera permission:', error);
            return 'error';
        }
    };

    // Function to attempt camera access
    const attemptCameraAccess = async () => {
        try {
            // Specify the back camera using 'facingMode: environment'
            const constraints = {
                video: {
                    facingMode: 'environment' // Use the back camera
                }
            };

            stream = await navigator.mediaDevices.getUserMedia(constraints);
            cameraView.srcObject = stream;
            cameraPlaceholder.classList.add('hide');
            cameraPreview.classList.remove('hide');
        } catch (error) {
            cameraPlaceholder.innerHTML = `
                <i class="fas fa-camera-slash fa-4x grey-text"></i>
                <p class="grey-text">Erro ao acessar a câmera.</p>
                <p class="grey-text">Por favor, permita o acesso à câmera.</p>
                <button id="try-again-button" class="btn waves-effect waves-light">
                    <i class="fas fa-sync-alt"></i> Tentar Novamente
                </button>
            `;
            cameraPlaceholder.style.cursor = 'default';

            // Add event listener to the "Try Again" button
            const tryAgainButton = document.getElementById('try-again-button');
            tryAgainButton.addEventListener('click', attemptCameraAccess);
        }
    };

    // Show camera preview when placeholder is clicked
    cameraPlaceholder.addEventListener('click', async () => {
        // Check camera permission
        const permissionState = await checkCameraPermission();

        if (permissionState === 'denied') {
            cameraPlaceholder.innerHTML = `
                <i class="fas fa-camera-slash fa-4x grey-text"></i>
                <p class="grey-text">Acesso à câmera negado.</p>
                <p class="grey-text">Por favor, permita o acesso nas configurações do dispositivo.</p>
                <button id="try-again-button" class="btn waves-effect waves-light">
                    <i class="fas fa-sync-alt"></i> Tentar Novamente
                </button>
            `;
            cameraPlaceholder.style.cursor = 'default';

            // Add event listener to the "Try Again" button
            const tryAgainButton = document.getElementById('try-again-button');
            tryAgainButton.addEventListener('click', attemptCameraAccess);
            return;
        }

        // Attempt to access the camera
        await attemptCameraAccess();
    });

    // Capture photo
    captureButton.addEventListener('click', () => {
        const canvas = document.createElement('canvas');
        canvas.width = cameraView.videoWidth;
        canvas.height = cameraView.videoHeight;
        canvas.getContext('2d').drawImage(cameraView, 0, 0, canvas.width, canvas.height);

        // Convert the captured image to a base64 string
        capturedPhoto = canvas.toDataURL('image/png').split(',')[1]; // Remove the data URL prefix

        // Display captured image
        capturedImage.src = canvas.toDataURL('image/png');
        cameraPreview.classList.add('hide');
        capturedImageContainer.classList.remove('hide');
        confirmButton.classList.remove('hide');

        // Stop camera stream
        if (stream) {
            stream.getTracks().forEach(track => track.stop());
        }
    });

    // Retake photo
    retakeButton.addEventListener('click', () => {
        capturedImageContainer.classList.add('hide');
        confirmButton.classList.add('hide');
        cameraPlaceholder.classList.remove('hide');
        cameraPreview.classList.remove('hide');
        capturedPhoto = null; // Clear the captured photo
    });

    // Confirm button click handler
    confirmButton.addEventListener('click', async () => {
        const serialNumber = serialNumberInput.value.trim();

        if (!serialNumber) {
            alert('Por favor, informe o número de série.');
            return;
        }

        // Prepare the message object
        const message = {
            text: `Número de série: ${serialNumber}`,
        };

        // Add the photo to the message if it was captured
        if (capturedPhoto) {
            message.file = {
                base64: capturedPhoto,
                name: 'equipamento.png', // Name of the file
            };
        }

        // Send the message to the chat
        try {
            await window.webxdc.sendToChat(message);
            alert('Mensagem enviada com sucesso!');
        } catch (error) {
            console.error('Erro ao enviar mensagem:', error);
            alert('Erro ao enviar mensagem. Por favor, tente novamente.');
        }
    });
});